eprllib.Utils.Utils
===================

.. automodule:: eprllib.Utils.Utils

   
   .. rubric:: Functions

   .. autosummary::
   
      building_dimension
      calcular_centro
      effective_thermal_capacity
      fenestration_area
      find_dict_key_by_nested_key
      generate_occupancy_schedule
      generate_variated_schedule
      generate_variated_schedule_with_shift
      inertial_mass_calculation
      material_area
      random_building_config
      u_factor
      u_factor_calculation
      variable_checking
      window_size_epJSON
   